interface Levels {
    success: 0;
    debug: 1;
    info: 2;
    notice: 3;
    warn: 4;
    error: 5;
}
declare type LevelString = keyof Levels;
declare type LevelNumber = 0 | 1 | 2 | 3 | 4 | 5;
interface IObject {
    [key: string]: any;
}
interface LoggerOptions extends IObject {
    level?: LevelString | LevelNumber;
    format?: string | null;
    datetimeFormat?: string;
    msgColor?: boolean;
    wrapLabel?: boolean;
    uppercaseLabel?: boolean;
    colors?: {
        [key: string]: Function;
    };
}
interface LoggerProps extends IObject {
    label?: string;
    msg?: string;
    datetime?: string;
}
declare class Logger {
    level: LevelString | LevelNumber;
    format: string;
    datetimeFormat: string;
    msgColor: boolean;
    wrapLabel: boolean;
    uppercaseLabel: boolean;
    colors: {
        success: (str: string | number) => string;
        debug: (str: string | number) => string;
        info: (str: string | number) => string;
        notice: (str: string | number) => string;
        warn: (str: string | number) => string;
        error: (str: string | number) => string;
    };
    constructor(options?: LoggerOptions);
    validFormat(format: string): boolean;
    convertLevel(level?: LevelString | LevelNumber): number;
    getCurrentDatetime(): string;
    replaces(props: LoggerProps): string;
    log(msg?: string, label?: string, color?: Function, level?: LevelString | LevelNumber): void;
    text(msg?: string, color?: Function): void;
    enter(): void;
    formatLabel(label: string): string;
    success(msg?: string, label?: string): void;
    debug(msg?: string, label?: string): void;
    info(msg?: string, label?: string): void;
    notice(msg?: string, label?: string): void;
    warn(msg?: string, label?: string): void;
    error(msg?: string, label?: string): void;
}

export default Logger;
export { IObject, LevelNumber, LevelString, Levels, Logger, LoggerOptions, LoggerProps };
