"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};

// src/logger.ts
var _kolorist = require('kolorist');
var _exceptionerror = require('exception-error');
var _dayjs = require('dayjs'); var _dayjs2 = _interopRequireDefault(_dayjs);
var ERROR = "XLoggerError";
var LEVELS = {
  success: 0,
  debug: 1,
  info: 2,
  notice: 3,
  warn: 4,
  error: 5
};
var Logger = class {
  constructor(options) {
    __publicField(this, "level", 0);
    __publicField(this, "format", "[label] [msg]");
    __publicField(this, "datetimeFormat", "YYYY-MM-DD HH:mm:ss");
    __publicField(this, "msgColor", false);
    __publicField(this, "wrapLabel", false);
    __publicField(this, "uppercaseLabel", false);
    __publicField(this, "colors", {
      success: _kolorist.green,
      debug: _kolorist.magenta,
      info: _kolorist.cyan,
      notice: _kolorist.blue,
      warn: _kolorist.yellow,
      error: _kolorist.red
    });
    const opts = options != null ? options : {};
    this.level = opts.level || this.level;
    this.format = opts.format || this.format;
    this.datetimeFormat = opts.datetimeFormat || this.datetimeFormat;
    this.msgColor = !!opts.msgColor;
    this.wrapLabel = !!opts.wrapLabel;
    this.uppercaseLabel = !!opts.uppercaseLabel;
    this.colors = __spreadValues(__spreadValues({}, this.colors), (options == null ? void 0 : options.colors) || {});
    if (!this.validFormat(this.format)) {
      throw _exceptionerror.error.call(void 0, { code: ERROR, msg: "invalid format, such as [label] [msg]" });
    }
  }
  validFormat(format) {
    const reg = /(\[[a-z]+]).*?/g;
    return reg.test(format);
  }
  convertLevel(level) {
    let levelNumber = 0;
    if (typeof level === "string") {
      levelNumber = LEVELS[level] || 0;
    } else if (typeof level === "number") {
      levelNumber = level;
    }
    return levelNumber;
  }
  getCurrentDatetime() {
    return _dayjs2.default.call(void 0, ).format(this.datetimeFormat);
  }
  replaces(props) {
    var _a;
    let format = this.format;
    const pattern = /(\[[a-z]+]).*?/g;
    const propsKeys = Object.keys(props);
    const formatKeys = ((_a = format.match(pattern)) == null ? void 0 : _a.map((x) => x.replace("[", "").replace("]", "")).filter((f) => propsKeys.includes(f))) || [];
    for (const key of formatKeys) {
      format = format.replace(`[${key}]`, props[key]);
    }
    return format;
  }
  log(msg, label = "log", color, level) {
    const levelNumber = this.convertLevel(level);
    if (levelNumber < this.level)
      return;
    let newlineCharacter = "";
    if (msg == null ? void 0 : msg.startsWith("\n")) {
      newlineCharacter = (msg.match(/^\n+/) || [])[0];
      msg = msg == null ? void 0 : msg.replace(/^\n+/, "");
    }
    label = this.formatLabel(label);
    const props = {
      label: color && color(label) || label,
      msg,
      datetime: this.getCurrentDatetime()
    };
    if (this.format) {
      msg = this.replaces(props);
    }
    if (newlineCharacter) {
      msg = newlineCharacter + msg;
    }
    if (color && this.msgColor) {
      msg = color(msg);
    }
    console.log(msg);
  }
  text(msg, color) {
    msg = color ? color(msg) : msg;
    console.log(msg);
  }
  enter() {
    console.log();
  }
  formatLabel(label) {
    const labels = ["log", ...Object.keys(LEVELS)];
    if (labels.includes(label) && this.uppercaseLabel) {
      label = label.toUpperCase();
    }
    label = this.wrapLabel ? `[${label}]` : label;
    return label;
  }
  success(msg, label = "success") {
    this.log(msg, label, this.colors.success, 0);
  }
  debug(msg, label = "debug") {
    this.log(msg, label, this.colors.debug, 1);
  }
  info(msg, label = "info") {
    this.log(msg, label, this.colors.info, 2);
  }
  notice(msg, label = "notice") {
    this.log(msg, label, this.colors.notice, 3);
  }
  warn(msg, label = "warn") {
    this.log(msg, label, this.colors.warn, 4);
  }
  error(msg, label = "error") {
    this.log(msg, label, this.colors.error, 5);
  }
};

// src/index.ts
var src_default = Logger;



exports.Logger = Logger; exports.default = src_default;
